@@ -13,6 +13,8 @@ c   This is the interface to draw new volumes.
 c      
       if(comp.struc(1:8) .eq. 'angle') then
          call epDraw_angle(comp, p, n)
+      elseif(comp.struc(1:8) .eq. 'sqpipe') then
+         call epDraw_sqpipe(comp, p, n)
 c---  elseif(comp.struc(1:8) .eq. '%2') then
 c---     call epDraw_%2(comp, p, n)
       else
