@@ -192,5 +192,6 @@ c       r.l                         cm   / X0
 c         Det.cmp(Cn).MaxPathL may be < 0; which means
 c        that the value is set by Epics and abs should be used.
 c         already dummy
-      call ep2cosCond(Media(MediaNo).Aeff, Media(MediaNo).Zeff)
+c      call ep2cosCond(Media(MediaNo).Aeff, Media(MediaNo).Zeff)
+      call ep2cosCond
       end
