@@ -1256,7 +1256,15 @@ c
 c               stopped one. add decay time if possible
           call cgetctau(cTrack.p, ctau)
           if(ctau .eq. Infty) then
-             Move.Track.t= cTrack.t+1.e8
+c               If the particle is still to be treated
+c               even after it stops, the ptcl 
+c               should be antiprpton or anti-somthing to
+c               anihilate in the next step. We assume
+c               the anihilation takes place instantly
+c               after stopping. so don't add any time
+c               
+c                Move.Track.t= cTrack.t+1.e8  ! version <= 8.62
+                Move.Track.t = cTrack.t
           else
              call rndc(u)
              Move.Track.t = cTrack.t - log(u)*ctau
@@ -1388,7 +1396,6 @@ c
 
 c             sample energies of compton elec. and gamma
        call epcompea(cTrack.p.fm.p(4), eg, e1, cosg, cose)
-
        tmp=1.d0-cose*cose
        if(tmp .lt. 0.d0) then
           tmp=0.d0
@@ -1408,7 +1415,6 @@ c            w  get new direc-cos
        call cmkptc(kelec, regptcl, -1, electron.p)
        electron.p.fm.p(4) = e1
        call epe2p(electron)
-
 c
 c                treat gamma as counterpart of electron (negative d.c)
 c
