@@ -39,6 +39,7 @@ c              read control parameters
 
         character*150 msg
         character*100 cosmosparam
+        integer i, klena, n
 c
         cosmosparam  = ' '
         read(*, *, end=100) EpicsFile, ConfigFile, SepicsFile, cont,
@@ -67,7 +68,24 @@ c              incident energy sampling. initializaiton
            Inp1ry = 1
            call siniPrim(PrimaryFile)
         else
+c           PrimaryFile may contain: e.g     ../Input/+primary 
            Inp1ry = 0
+           i = 1
+           n = klena(PrimaryFile)
+           do i = n-1, 1, -1
+              if(PrimaryFile(i:i) .eq.  '/') then
+c                   the last / found
+                 if(PrimaryFile(i:i+1) .eq. '/+') then
+c                         it shouyld be file name with + at head
+                    Inp1ry = 1
+                    call siniPrim(PrimaryFile)
+                 endif
+                 goto 99
+              endif
+           enddo
+        endif
+ 99     continue
+        if(Inp1ry .eq. 0 ) then
            Inpxyz = 0
            Inpdir = 0
            Inperg  = 0
@@ -75,9 +93,7 @@ c              incident energy sampling. initializaiton
            Inpdisk = 0
            Inpuser = 0
            call ciniSPrim(PrimaryFile)
-
         endif
-
 c
 c            inquire form
         call epqfrm(formx)
